@@ -6,7 +6,6 @@ import runpy
 import functools
 
 # 3rd party
-import sphinx_rtd_theme
 import sphinx.environment
 from docutils.utils import get_source_line
 
@@ -155,7 +154,7 @@ html_theme = "sphinx_rtd_theme"
 # html_theme_options = {}
 
 # Add any paths that contain custom themes here, relative to this directory.
-html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
+# html_theme_path = []
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
@@ -277,7 +276,7 @@ autodoc_member_order = 'bysource'
 
 # when linking to standard python library, use and prefer python 3
 # documentation.
-intersphinx_mapping = {'https://docs.python.org/3/': None}
+intersphinx_mapping = {'python': ('https://docs.python.org/3', None)}
 
 # Both the class’ and the __init__ method’s docstring are concatenated and
 # inserted.
