@@ -25,8 +25,7 @@ else:
 def fn_tparm(*args):
     """Mock tparm function"""
     return u'~'.join(
-        arg.decode('latin1') if not num else '%s' % (arg,)
-        for num, arg in enumerate(args)
+        str(arg) if num else arg.decode('latin1') for num, arg in enumerate(args)
     ).encode('latin1')
 
 
@@ -205,7 +204,7 @@ def test_resolve_capability(monkeypatch):
         return ('seq-%s' % (attr,)).encode('latin1')
     monkeypatch.setattr(curses, 'tigetstr', tigetstr)
     term = mock.Mock()
-    term._sugar = dict(mnemonic='xyz')
+    term._sugar = {'mnemonic': 'xyz'}
 
     # exercise
     assert resolve_capability(term, 'mnemonic') == u'seq-xyz'
@@ -281,8 +280,8 @@ def test_resolve_attribute_as_color(monkeypatch):
 
     def resolve_color(term, digit):
         return 'seq-%s' % (digit,)
-    COLORS = set(['COLORX', 'COLORY'])
-    COMPOUNDABLES = set(['JOINT', 'COMPOUND'])
+    COLORS = {'COLORX', 'COLORY'}
+    COMPOUNDABLES = {'JOINT', 'COMPOUND'}
     monkeypatch.setattr(blessed.formatters, 'resolve_color', resolve_color)
     monkeypatch.setattr(blessed.formatters, 'COLORS', COLORS)
     monkeypatch.setattr(blessed.formatters, 'COMPOUNDABLES', COMPOUNDABLES)
@@ -297,7 +296,7 @@ def test_resolve_attribute_as_compoundable(monkeypatch):
 
     def resolve_cap(term, digit):
         return 'seq-%s' % (digit,)
-    COMPOUNDABLES = set(['JOINT', 'COMPOUND'])
+    COMPOUNDABLES = {'JOINT', 'COMPOUND'}
     monkeypatch.setattr(blessed.formatters,
                         'resolve_capability',
                         resolve_cap)
