@@ -10,10 +10,10 @@ import signal
 import platform
 
 # 3rd party
-import six
 import pytest
 
 # local
+from blessed._compat import PY2, StringIO
 from .accessories import (SEMAPHORE,
                           RECV_SEMAPHORE,
                           SEND_SEMAPHORE,
@@ -23,7 +23,7 @@ from .accessories import (SEMAPHORE,
                           read_until_eof,
                           read_until_semaphore,
                           init_subproc_coverage)
-from.conftest import IS_WINDOWS, TEST_KEYBOARD, TEST_QUICK, TEST_RAW
+from .conftest import IS_WINDOWS, TEST_KEYBOARD, TEST_QUICK, TEST_RAW
 
 try:
     from unittest import mock
@@ -136,7 +136,7 @@ def test_kbhit_no_kb():
     """kbhit() always immediately returns False without a keyboard."""
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
         stime = time.time()
         assert term._keyboard_fd is None
         assert not term.kbhit(timeout=1.1)
@@ -149,7 +149,7 @@ def test_kbhit_no_tty():
     @as_subprocess
     def child():
         with mock.patch('blessed.terminal.HAS_TTY', False):
-            term = TestTerminal(stream=six.StringIO())
+            term = TestTerminal(stream=StringIO())
             stime = time.time()
             assert term.kbhit(timeout=1.1) is False
             assert math.floor(time.time() - stime) == 0
@@ -173,7 +173,7 @@ def test_keystroke_0s_cbreak_noinput_nokb():
     """0-second keystroke without data in input stream and no keyboard/tty."""
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
         with term.cbreak():
             stime = time.time()
             inp = term.inkey(timeout=0)
@@ -201,7 +201,7 @@ def test_keystroke_1s_cbreak_noinput_nokb():
     """1-second keystroke without input or keyboard."""
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
         with term.cbreak():
             stime = time.time()
             inp = term.inkey(timeout=1)
@@ -582,7 +582,7 @@ def test_get_location_0s():
     """0-second get_location call without response."""
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
         stime = time.time()
         y, x = term.get_location(timeout=0)
         assert (math.floor(time.time() - stime) == 0.0)
@@ -650,7 +650,7 @@ def test_get_location_0s_reply_via_ungetch():
     """0-second get_location call with response."""
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
         stime = time.time()
         # monkey patch in an invalid response !
         term.ungetch(u'\x1b[10;10R')
@@ -667,7 +667,7 @@ def test_get_location_0s_nonstandard_u6():
 
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
 
         stime = time.time()
         # monkey patch in an invalid response !
@@ -685,12 +685,12 @@ def test_get_location_styling_indifferent():
     """Ensure get_location() behavior is the same regardless of styling"""
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO(), force_styling=True)
+        term = TestTerminal(stream=StringIO(), force_styling=True)
         term.ungetch(u'\x1b[10;10R')
         y, x = term.get_location(timeout=0.01)
         assert (y, x) == (9, 9)
 
-        term = TestTerminal(stream=six.StringIO(), force_styling=False)
+        term = TestTerminal(stream=StringIO(), force_styling=False)
         term.ungetch(u'\x1b[10;10R')
         y, x = term.get_location(timeout=0.01)
         assert (y, x) == (9, 9)
@@ -701,7 +701,7 @@ def test_get_location_timeout():
     """0-second get_location call with response."""
     @as_subprocess
     def child():
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
         stime = time.time()
         # monkey patch in an invalid response !
         term.ungetch(u'\x1b[0n')
@@ -712,7 +712,91 @@ def test_get_location_timeout():
     child()
 
 
-@pytest.mark.skipif(six.PY2, reason="Python 3 only")
+def test_get_fgcolor_0s():
+    """0-second get_fgcolor call without response."""
+    @as_subprocess
+    def child():
+        term = TestTerminal(stream=StringIO())
+        stime = time.time()
+        rgb = term.get_fgcolor(timeout=0)
+        assert math.floor(time.time() - stime) == 0.0
+        assert rgb == (-1, -1, -1)
+    child()
+
+
+def test_get_fgcolor_0s_reply_via_ungetch():
+    """0-second get_fgcolor call with response."""
+    @as_subprocess
+    def child():
+        term = TestTerminal(stream=StringIO())
+        stime = time.time()
+        term.ungetch(u'\x1b]10;rgb:a0/52/2d\x07')  # sienna
+
+        rgb = term.get_fgcolor(timeout=0.01)
+        assert math.floor(time.time() - stime) == 0.0
+        assert rgb == (160, 82, 45)
+    child()
+
+
+def test_get_fgcolor_styling_indifferent():
+    """Ensure get_fgcolor() behavior is the same regardless of styling"""
+    @as_subprocess
+    def child():
+        term = TestTerminal(stream=StringIO(), force_styling=True)
+        term.ungetch(u'\x1b]10;rgb:d2/b4/8c\x07')  # tan
+        rgb = term.get_fgcolor(timeout=0.01)
+        assert rgb == (210, 180, 140)
+
+        term = TestTerminal(stream=StringIO(), force_styling=False)
+        term.ungetch(u'\x1b]10;rgb:40/e0/d0\x07')  # turquoise
+        rgb = term.get_fgcolor(timeout=0.01)
+        assert rgb == (64, 224, 208)
+    child()
+
+
+def test_get_bgcolor_0s():
+    """0-second get_bgcolor call without response."""
+    @as_subprocess
+    def child():
+        term = TestTerminal(stream=StringIO())
+        stime = time.time()
+        rgb = term.get_bgcolor(timeout=0)
+        assert math.floor(time.time() - stime) == 0.0
+        assert rgb == (-1, -1, -1)
+    child()
+
+
+def test_get_bgcolor_0s_reply_via_ungetch():
+    """0-second get_bgcolor call with response."""
+    @as_subprocess
+    def child():
+        term = TestTerminal(stream=StringIO())
+        stime = time.time()
+        term.ungetch(u'\x1b]11;rgb:99/32/cc\x07')  # darkorchid
+
+        rgb = term.get_bgcolor(timeout=0.01)
+        assert math.floor(time.time() - stime) == 0.0
+        assert rgb == (153, 50, 204)
+    child()
+
+
+def test_get_bgcolor_styling_indifferent():
+    """Ensure get_bgcolor() behavior is the same regardless of styling"""
+    @as_subprocess
+    def child():
+        term = TestTerminal(stream=StringIO(), force_styling=True)
+        term.ungetch(u'\x1b]11;rgb:ff/e4/c4\x07')  # bisque
+        rgb = term.get_bgcolor(timeout=0.01)
+        assert rgb == (255, 228, 196)
+
+        term = TestTerminal(stream=StringIO(), force_styling=False)
+        term.ungetch(u'\x1b]11;rgb:de/b8/87\x07')  # burlywood
+        rgb = term.get_bgcolor(timeout=0.01)
+        assert rgb == (222, 184, 135)
+    child()
+
+
+@pytest.mark.skipif(PY2, reason="Python 3 only")
 def test_detached_stdout():
     """Ensure detached __stdout__ does not raise an exception"""
     import pty
