@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Tests for keyboard support."""
 # std imports
-import sys
+import os
 import platform
 import tempfile
 import functools
@@ -10,6 +10,7 @@ import functools
 import pytest
 
 # local
+from blessed._compat import unicode_chr
 from .accessories import TestTerminal, as_subprocess
 from .conftest import IS_WINDOWS
 
@@ -24,9 +25,6 @@ if platform.system() != 'Windows':
 else:
     import jinxed as curses
 
-if sys.version_info[0] == 3:
-    unichr = chr
-
 
 @pytest.mark.skipif(IS_WINDOWS, reason="?")
 def test_break_input_no_kb():
@@ -93,8 +91,8 @@ def test_keystroke_default_args():
     assert ks.code == ks._code
     assert u'x' + ks == u'x'
     assert not ks.is_sequence
-    assert repr(ks) in ("u''",  # py26, 27
-                        "''",)  # py33
+    assert repr(ks) in {"u''",  # py26, 27
+                        "''"}  # py33
 
 
 def test_a_keystroke():
@@ -244,43 +242,43 @@ def test_resolve_sequence():
     assert ks.name is None
     assert ks.code is None
     assert not ks.is_sequence
-    assert repr(ks) in ("u''",  # py26, 27
-                        "''",)  # py33
+    assert repr(ks) in {"u''",  # py26, 27
+                        "''"}  # py33
 
     ks = resolve_sequence(u'notfound', mapper=mapper, codes=codes)
     assert ks == u'n'
     assert ks.name is None
     assert ks.code is None
     assert not ks.is_sequence
-    assert repr(ks) in (u"u'n'", "'n'",)
+    assert repr(ks) in {u"u'n'", "'n'"}
 
     ks = resolve_sequence(u'SEQ1', mapper, codes)
     assert ks == u'SEQ1'
     assert ks.name == u'KEY_SEQ1'
     assert ks.code == 1
     assert ks.is_sequence
-    assert repr(ks) in (u"KEY_SEQ1", "KEY_SEQ1")
+    assert repr(ks) == u"KEY_SEQ1"
 
     ks = resolve_sequence(u'LONGSEQ_longer', mapper, codes)
     assert ks == u'LONGSEQ'
     assert ks.name == u'KEY_LONGSEQ'
     assert ks.code == 4
     assert ks.is_sequence
-    assert repr(ks) in (u"KEY_LONGSEQ", "KEY_LONGSEQ")
+    assert repr(ks) == u"KEY_LONGSEQ"
 
     ks = resolve_sequence(u'LONGSEQ', mapper, codes)
     assert ks == u'LONGSEQ'
     assert ks.name == u'KEY_LONGSEQ'
     assert ks.code == 4
     assert ks.is_sequence
-    assert repr(ks) in (u"KEY_LONGSEQ", "KEY_LONGSEQ")
+    assert repr(ks) == u"KEY_LONGSEQ"
 
     ks = resolve_sequence(u'Lxxxxx', mapper, codes)
     assert ks == u'L'
     assert ks.name == u'KEY_L'
     assert ks.code == 6
     assert ks.is_sequence
-    assert repr(ks) in (u"KEY_L", "KEY_L")
+    assert repr(ks) == u"KEY_L"
 
 
 def test_keyboard_prefixes():
@@ -288,7 +286,7 @@ def test_keyboard_prefixes():
     from blessed.keyboard import get_leading_prefixes
     keys = ['abc', 'abdf', 'e', 'jkl']
     pfs = get_leading_prefixes(keys)
-    assert pfs == set([u'a', u'ab', u'abd', u'j', u'jk'])
+    assert pfs == {u'a', u'ab', u'abd', u'j', u'jk'}
 
 
 @pytest.mark.skipif(IS_WINDOWS, reason="no multiprocess")
@@ -310,12 +308,12 @@ def test_keypad_mixins_and_aliases():  # pylint: disable=too-many-statements
                                     mapper=term._keymap,
                                     codes=term._keycodes)
 
-        assert resolve(unichr(10)).name == "KEY_ENTER"
-        assert resolve(unichr(13)).name == "KEY_ENTER"
-        assert resolve(unichr(8)).name == "KEY_BACKSPACE"
-        assert resolve(unichr(9)).name == "KEY_TAB"
-        assert resolve(unichr(27)).name == "KEY_ESCAPE"
-        assert resolve(unichr(127)).name == "KEY_BACKSPACE"
+        assert resolve(unicode_chr(10)).name == "KEY_ENTER"
+        assert resolve(unicode_chr(13)).name == "KEY_ENTER"
+        assert resolve(unicode_chr(8)).name == "KEY_BACKSPACE"
+        assert resolve(unicode_chr(9)).name == "KEY_TAB"
+        assert resolve(unicode_chr(27)).name == "KEY_ESCAPE"
+        assert resolve(unicode_chr(127)).name == "KEY_BACKSPACE"
         assert resolve(u"\x1b[A").name == "KEY_UP"
         assert resolve(u"\x1b[B").name == "KEY_DOWN"
         assert resolve(u"\x1b[C").name == "KEY_RIGHT"
@@ -363,3 +361,32 @@ def test_keypad_mixins_and_aliases():  # pylint: disable=too-many-statements
         assert resolve(u"\x1bOS").name == "KEY_F4"
 
     child('xterm')
+
+
+def test_ESCDELAY_unset_unchanged():
+    """Unset ESCDELAY leaves DEFAULT_ESCDELAY unchanged in _reinit_escdelay()."""
+    if 'ESCDELAY' in os.environ:
+        del os.environ['ESCDELAY']
+    import blessed.keyboard
+    prev_value = blessed.keyboard.DEFAULT_ESCDELAY
+    blessed.keyboard._reinit_escdelay()
+    assert blessed.keyboard.DEFAULT_ESCDELAY == prev_value
+
+
+def test_ESCDELAY_bad_value_unchanged():
+    """Invalid ESCDELAY leaves DEFAULT_ESCDELAY unchanged in _reinit_escdelay()."""
+    os.environ['ESCDELAY'] = 'XYZ123!'
+    import blessed.keyboard
+    prev_value = blessed.keyboard.DEFAULT_ESCDELAY
+    blessed.keyboard._reinit_escdelay()
+    assert blessed.keyboard.DEFAULT_ESCDELAY == prev_value
+    del os.environ['ESCDELAY']
+
+
+def test_ESCDELAY_10ms():
+    """Verify ESCDELAY modifies DEFAULT_ESCDELAY in _reinit_escdelay()."""
+    os.environ['ESCDELAY'] = '1234'
+    import blessed.keyboard
+    blessed.keyboard._reinit_escdelay()
+    assert blessed.keyboard.DEFAULT_ESCDELAY == 1.234
+    del os.environ['ESCDELAY']
