@@ -9,10 +9,10 @@ import platform
 import itertools
 
 # 3rd party
-import six
 import pytest
 
 # local
+from blessed._compat import StringIO
 from .accessories import TestTerminal, as_subprocess
 from .conftest import IS_WINDOWS
 
@@ -37,6 +37,21 @@ def test_length_cjk():
     child()
 
 
+def test_length_with_zwj_is_wrong():
+    """Because of the way Zero-Width Joiner (ZWJ) is measured, blessed gets this wrong"""
+    # But for the time being, so do many terminals (~85%), so its not a huge deal..
+    # https://ucs-detect.readthedocs.io/results.html
+    @as_subprocess
+    def child():
+        term = TestTerminal()
+        # RGI_Emoji_ZWJ_Sequence  ; family: woman, woman, girl, boy
+        given = term.bold_red(u'\U0001F469\u200D\U0001F469\u200D\U0001F467\u200D\U0001F466')
+        expected = sum((2, 0, 2, 0, 2, 0, 2))
+
+        # exercise,
+        assert term.length(given) == expected
+
+
 def test_length_ansiart():
     """Test length of ANSI art"""
     @as_subprocess
@@ -60,7 +75,7 @@ def test_length_ansiart():
 
 
 def test_sequence_length(all_terms):
-    """Ensure T.length(string containing sequence) is correcterm."""
+    """Ensure T.length(string containing sequence) is correct."""
     # pylint: disable=too-complex,too-many-statements
     @as_subprocess
     def child(kind):
@@ -308,7 +323,7 @@ def test_env_winsize():
         # set the pty's virtual window size
         os.environ['COLUMNS'] = '99'
         os.environ['LINES'] = '11'
-        term = TestTerminal(stream=six.StringIO())
+        term = TestTerminal(stream=StringIO())
         save_init = term._init_descriptor
         save_stdout = sys.__stdout__
         try:
@@ -335,6 +350,7 @@ def test_winsize(many_lines, many_columns):
     def child(lines=25, cols=80):
         # set the pty's virtual window size
         val = struct.pack('HHHH', lines, cols, pixel_width, pixel_height)
+        # pylint: disable-next=possibly-used-before-assignment
         fcntl.ioctl(sys.__stdout__.fileno(), termios.TIOCSWINSZ, val)
         term = TestTerminal()
         winsize = term._height_and_width()
